@@ -1,4 +1,4 @@
-//  Copyright (C) 1999 Silicon Graphics, Inc.  All Rights Reserved.
+//  Copyright (C) 1999-2003 Silicon Graphics, Inc.  All Rights Reserved.
 //  
 //  This program is free software; you can redistribute it and/or modify it
 //  under the terms of version 2.1 of the GNU Lesser General Public License
@@ -26,24 +26,9 @@
 #include <assert.h>
 #include "config.h"
 
-#if !(HAVE_BOOL)
-
+#if !HAVE_BOOL
 typedef int bool;
 const bool true(1), false(0);
-
-#endif  /*  !(HAVE_BOOL)  */
-
-
-//#ifndef HAVE_FOO
-/*  Definitions in support/foo.c++ */
-//extern void foo();
-//#endif
-
-//#ifndef HAVE_SNPRINTF
-/*  Definitions in support/snprintf.c++ */
-//extern int snprintf(char *buf, size_t len, const char *fmt, ...);
-//extern int vsnprintf(char *buf, size_t len, const char *fmt, va_list);
-//#endif
-
+#endif
 
 #endif /* !Boolean_included */
